Summary:  Kernel Virtual Machine virtualization environment
Name:     kvm
Version:  82
Release:  %mkrel 1
License:  GPLv2+ and LGPLv2+
Group:    Emulators
Url:      http://kvm.qumranet.com/
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
Source0:  %{name}-%{version}.tar.gz
# Fix dead keys and Alt-Gr on some keyboards
# http://lists.gnu.org/archive/html/qemu-devel/2008-11/msg00116.html
Patch0:   kvm-78-keys.patch
Patch1:   kvm-82-format-string.patch
BuildRequires:  dev86
BuildRequires:  iasl
BuildRequires:  zlib-devel
BuildRequires:  SDL-devel
BuildRequires:  texi2html
BuildRequires:	pulseaudio-devel

%description
KVM (for Kernel-based Virtual Machine) is a full virtualization solution for
Linux on x86 hardware containing virtualization extensions (Intel VT or
AMD-V). It consists of a loadable kernel module, kvm.ko, that provides the
core virtualization infrastructure and a processor specific module,
kvm-intel.ko or kvm-amd.ko.

Using KVM, one can run multiple virtual machines running unmodified Linux or
Windows images. Each virtual machine has private virtualized hardware: a
network card, disk, graphics adapter, etc.


%prep
%setup -q
%patch0 -p1 -b .keys
%patch1 -p1 -b .sfmt

%build
# we need to install the data bits in a different path
sed -i 's/datasuffix=\"\/share\/qemu\"/datasuffix=\"\/share\/kvm\"/' qemu/configure
./configure --prefix=%_prefix --arch=%_target_cpu --qemu-cflags="%{optflags}" --audio-drv-list=pa,alsa,oss
sed -i 's/gcc -m32/gcc/' bios/Makefile
make libkvm user qemu bios vgabios extboot

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} WANT_MODULE="" install

mv %{buildroot}%{_mandir}/man1/qemu.1 %{buildroot}%{_mandir}/man1/kvm.1
chmod a-x %{buildroot}%{_mandir}/man1/kvm.1

rm -rf %{buildroot}%{_mandir}/man*/qemu-{img,nbd}*
rm -f %{buildroot}%{_bindir}/{qemu-img,qemu-nbd}
rm -rf %{buildroot}%{_docdir}/qemu

# no shared lib, static libs
rm -fr %{buildroot}%{_includedir} %{buildroot}%{_libdir}

# We're only build x86, so kill other BIOS to save disk space
rm -f %{buildroot}%{_datadir}/%{name}/{openbios-sparc*,ppc_rom.bin,video.x}

mv %{buildroot}%{_bindir}/qemu* %{buildroot}%{_bindir}/kvm

install -D user/{kvmctl,kvmtrace,kvmtrace_format} %{buildroot}%{_bindir}

mkdir -p %{buildroot}%{_sysconfdir}/udev/rules.d/
cat > %{buildroot}%{_sysconfdir}/udev/rules.d/65-kvm.rules << EOF
KERNEL=="kvm", MODE="0666"
EOF

ln -s kvm %{buildroot}%{_bindir}/qemu-kvm
 
%clean
rm -rf %{buildroot}


%files
%defattr(-,root,root)
%doc qemu/qemu-{doc,tech}.html
%{_bindir}/kvm
%{_bindir}/kvmctl
%{_bindir}/kvmtrace
%{_bindir}/kvmtrace_format
%{_bindir}/qemu-kvm
%dir %{_datadir}/kvm
%{_datadir}/kvm/*
/usr/share/man/man1/kvm.1.lzma
%_sysconfdir/udev/rules.d/65-kvm.rules


%changelog
* Sat Dec 27 2008 Frederik Himpe <fhimpe@mandriva.org> 82-1mdv2009.1
+ Revision: 320016
- Update to new version 82
- Fix string format errors

* Wed Nov 12 2008 Frederik Himpe <fhimpe@mandriva.org> 79-1mdv2009.1
+ Revision: 302551
- Update to new version 79

* Sat Nov 08 2008 Frederik Himpe <fhimpe@mandriva.org> 78-1mdv2009.1
+ Revision: 300926
- Update to new version 78
- Disable parallel build, it's broken
- Add patch to fix dead keys and Alt-Gr keys on some keyboards
- Build with Alsa and PulseAudio support in addition to OSS

* Wed Oct 29 2008 Frederik Himpe <fhimpe@mandriva.org> 77-3mdv2009.1
+ Revision: 298639
- Update to new version 77

* Thu Oct 16 2008 Pascal Terjan <pterjan@mandriva.org> 74-3mdv2009.1
+ Revision: 294150
- Add qemu-kvm symlink (#44929)

* Sun Sep 28 2008 Pascal Terjan <pterjan@mandriva.org> 74-2mdv2009.0
+ Revision: 289047
- Add 65-kvm.rules back (#44349)

* Sat Sep 13 2008 Pascal Terjan <pterjan@mandriva.org> 74-1mdv2009.0
+ Revision: 284360
- BuildRequires zlib-devel and texi2html
- BuildRequires iasl
- import kvm


